#!/usr/bin/env bash

# ---------------------------------------------
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corporation 2021
# ---------------------------------------------

# source configure before installing
TA_LOCAL_CONFIG=./.configuration
TA_LOCAL_CONFIG_DEV=./.configuration.dev

# if there is dev file, use it
if [ -f "$TA_LOCAL_CONFIG_DEV" ]; then
  echo "$TA_LOCAL_CONFIG_DEV is provided. Using dev file."
  source "$TA_LOCAL_CONFIG_DEV"
else
  source "$TA_LOCAL_CONFIG"
fi

###create the podman/docker alias
if [[ $TA_LOCAL_TEMP_PODMAN_INSTALL = true ]]; then
  shopt -s expand_aliases
  source ./.podman_config
fi


source ./.security_config


function imagePull {

 cmd3=$(docker images | grep transformation-advisor-server | awk '{print $1}')
 cmd4=$(docker images | grep transformation-advisor-ui | awk '{print $1}')
 cmd5=$(docker images | grep transformation-advisor-db | awk '{print $1}')
 cmd7=$(docker images | grep transformation-advisor-neo4j | awk '{print $1}')

   if [[ -z $cmd3 ]] && [[ -z $cmd4 ]] && [[ -z $cmd5 ]] && [[ -z $cmd7 ]]; then
      echo "Status"
      echo "------------------------------------------------------------------------------------------------------"
      echo "Transformation Advisor images are not pulled..."

	docker pull "${TA_LOCAL_CONFIG_COUCH_IMAGE}" #>../logs/PullinggraphDB_$(date +"%Y%m%d_%H%M%S").log
	docker pull "${TA_LOCAL_CONFIG_SERVER_IMAGE}" #>../logs/PullingcouchDB_$(date +"%Y%m%d_%H%M%S").log
	docker pull "${TA_LOCAL_CONFIG_UI_IMAGE}" #>../logs/PullingserverDB_$(date +"%Y%m%d_%H%M%S").log
	docker pull "${TA_LOCAL_CONFIG_NEO4J_IMAGE}" #>../logs/PullinguiDB_$(date +"%Y%m%d_%H%M%S").log

fi
}

function imageRun {

# we prioritise to use docker if available
if [[ $TA_LOCAL_TEMP_DOCKER_INSTALL = true ]]; then

	if uname -s | grep 'Darwin' >/dev/null; then
		# sed commands modified for mac
		sed -i '' -e  's/<contServer>/taserver/g' .env
		sed -i '' -e  's/<contUI>/taui/g' .env
		sed -i '' -e  's/<contDB>/tadb/g' .env
		sed -i '' -e  's/<contGraph>/tagraph/g' .env
                sed -i '' -e 's/<internal_port>/'${TA_LOCAL_INTERNAL_SERVER_PORT}'/g' .env
		sed -i '' -e 's/<server_port>/'${TA_EXTERNAL_PORT_SERVER}'/g' .env
	else
		sed -i 's/<contServer>/taserver/g' .env
		sed -i 's/<contUI>/taui/g' .env
		sed -i 's/<contDB>/tadb/g' .env
		sed -i 's/<contGraph>/tagraph/g' .env
                sed -i 's/<internal_port>/'${TA_LOCAL_INTERNAL_SERVER_PORT}'/g' .env
		sed -i 's/<server_port>/'${TA_EXTERNAL_PORT_SERVER}'/g' .env
	fi

if uname -s | grep 'Darwin' >/dev/null; then

        docker network create ta_local 2>/dev/null
        docker run  -d --expose ${TA_LOCAL_INTERNAL_DB_PORT}  --net ta_local --name tadb --memory="${TA_LOCAL_CONFIG_COUCH_MEMORY}" --cpus="${TA_LOCAL_CONFIG_COUCH_CPU}" --env-file ./.env -v "$(pwd)/../data:/opt/couchdb/data" "${TA_LOCAL_CONFIG_COUCH_IMAGE}" #2>/dev/null

        docker run  -d -p ${TA_EXTERNAL_UI_PORT}:${TA_LOCAL_INTERNAL_UI_PORT} --net ta_local --name taui --memory="${TA_LOCAL_CONFIG_UI_MEMORY}" --cpus="${TA_LOCAL_CONFIG_UI_CPU}" --env-file ./.env "${TA_LOCAL_CONFIG_UI_IMAGE}" #2>/dev/null

        docker run  -d -p ${TA_EXTERNAL_PORT_SERVER}:${TA_LOCAL_INTERNAL_SERVER_PORT} --net ta_local --name taserver  --memory="${TA_LOCAL_CONFIG_SERVER_MEMORY}" --cpus="${TA_LOCAL_CONFIG_SERVER_CPU}" --env-file ./.env "${TA_LOCAL_CONFIG_SERVER_IMAGE}" #2>/dev/null

        docker run  -d --expose 7687 --net ta_local --name tagraph --memory="${TA_LOCAL_CONFIG_NEO4J_MEMORY}" --cpus="${TA_LOCAL_CONFIG_NEO4J_CPU}" --env-file ./.env -v "$(pwd)/../graph_data:/data" "${TA_LOCAL_CONFIG_NEO4J_IMAGE}" #2>/dev/null

else

	docker network create ta_local 2>/dev/null 
	docker run  -d --expose ${TA_LOCAL_INTERNAL_DB_PORT}  --net ta_local --name tadb --memory="${TA_LOCAL_CONFIG_COUCH_MEMORY}" --cpus="${TA_LOCAL_CONFIG_COUCH_CPU}" --env-file ./.env -v "$(pwd)/../data:/opt/couchdb/data:Z" "${TA_LOCAL_CONFIG_COUCH_IMAGE}" #2>/dev/null

	docker run  -d -p ${TA_EXTERNAL_UI_PORT}:${TA_LOCAL_INTERNAL_UI_PORT} --net ta_local --name taui --memory="${TA_LOCAL_CONFIG_UI_MEMORY}" --cpus="${TA_LOCAL_CONFIG_UI_CPU}" --env-file ./.env "${TA_LOCAL_CONFIG_UI_IMAGE}" #2>/dev/null

	docker run  -d -p ${TA_EXTERNAL_PORT_SERVER}:${TA_LOCAL_INTERNAL_SERVER_PORT} --net ta_local --name taserver  --memory="${TA_LOCAL_CONFIG_SERVER_MEMORY}" --cpus="${TA_LOCAL_CONFIG_SERVER_CPU}" --env-file ./.env "${TA_LOCAL_CONFIG_SERVER_IMAGE}" #2>/dev/null

	docker run  -d --expose 7687 --net ta_local --name tagraph --memory="${TA_LOCAL_CONFIG_NEO4J_MEMORY}" --cpus="${TA_LOCAL_CONFIG_NEO4J_CPU}" --env-file ./.env -v "$(pwd)/../graph_data:/data:Z" "${TA_LOCAL_CONFIG_NEO4J_IMAGE}" #2>/dev/null

fi
else
	if uname -s | grep 'Darwin' >/dev/null; then
		# sed commands modified for mac
		sed -i '' -e  's/<contServer>/localhost/g' .env
		sed -i '' -e  's/<contUI>/localhost/g' .env
		sed -i '' -e  's/<contDB>/localhost/g' .env
		sed -i '' -e  's/<contGraph>/localhost/g' .env
                sed -i '' -e 's/<internal_port>/'${TA_LOCAL_INTERNAL_SERVER_PORT}'/g' .env
		sed -i '' -e 's/<server_port>/'${TA_EXTERNAL_PORT_SERVER}'/g' .env
	else
		sed -i 's/<contServer>/localhost/g' .env
		sed -i 's/<contUI>/localhost/g' .env
		sed -i 's/<contDB>/localhost/g' .env
		sed -i 's/<contGraph>/localhost/g' .env
                sed -i 's/<internal_port>/'${TA_LOCAL_INTERNAL_SERVER_PORT}'/g' .env
		sed -i 's/<server_port>/'${TA_EXTERNAL_PORT_SERVER}'/g' .env
	fi

     if [[ -f ./.machine_name ]]; then


        sleep 5
        podman run  -p 2222:5984 -d  --name tadb --env-file ./env_couch.list -v "$(pwd)/../data:/opt/couchdb/data:Z" "${TA_LOCAL_CONFIG_COUCH_IMAGE}"

        podman run  -p 7474:7474 -p 7687:7687 -d  --name tagraph --env-file  ./env_graph.list -v "$(pwd)/../graph_data:/data:Z"  "${TA_LOCAL_CONFIG_NEO4J_IMAGE}"

        podman run -p 2220:9080 -d  --name taserver  --env-file ./env_server.list "${TA_LOCAL_CONFIG_SERVER_IMAGE}"

        podman run -p 3000:3000 -d  --name taui  --env-file ./env_ui.list "${TA_LOCAL_CONFIG_UI_IMAGE}"

      elif uname -s | grep 'Darwin' >/dev/null; then

        podman pod create -n ta_pod -p ${TA_EXTERNAL_UI_PORT}:${TA_LOCAL_INTERNAL_UI_PORT} -p ${TA_EXTERNAL_PORT_SERVER}:${TA_LOCAL_INTERNAL_SERVER_PORT}

        podman run  -d --pod ta_pod --name tadb --env-file ./.env -v "tadb:/opt/couchdb/data" "${TA_LOCAL_CONFIG_COUCH_IMAGE}"

        podman run  -d --pod ta_pod --name tagraph --env-file  ./.env -v "tagraph:/data"  "${TA_LOCAL_CONFIG_NEO4J_IMAGE}"

        podman run -d --pod ta_pod --name taserver  --env-file ./.env "${TA_LOCAL_CONFIG_SERVER_IMAGE}"

        podman run -d --pod ta_pod --name taui  --env-file ./.env "${TA_LOCAL_CONFIG_UI_IMAGE}"


      else
	podman pod create -n ta_pod -p ${TA_EXTERNAL_UI_PORT}:${TA_LOCAL_INTERNAL_UI_PORT} -p ${TA_EXTERNAL_PORT_SERVER}:${TA_LOCAL_INTERNAL_SERVER_PORT}

	podman run  -d --pod ta_pod --name tadb --env-file ./.env -v "$(pwd)/../data:/opt/couchdb/data:Z" "${TA_LOCAL_CONFIG_COUCH_IMAGE}"

	podman run  -d --pod ta_pod --name tagraph --env-file  ./.env -v "$(pwd)/../graph_data:/data:Z"  "${TA_LOCAL_CONFIG_NEO4J_IMAGE}"

	podman run -d --pod ta_pod --name taserver  --env-file ./.env "${TA_LOCAL_CONFIG_SERVER_IMAGE}"

	podman run -d --pod ta_pod --name taui  --env-file ./.env "${TA_LOCAL_CONFIG_UI_IMAGE}"

   fi

   cp ./env_ui.list_orig ./env_ui.list
   cp ./env_server.list_orig ./env_server.list

fi

}

function startTA {

### Get the TA Docker Container IDs

ui=$(docker ps -a | grep transformation-advisor-ui | awk '{print $1}')
couch=$(docker ps -a | grep transformation-advisor-db | awk '{print $1}')
server=$(docker ps -a | grep transformation-advisor-server | awk '{print $1}')
neo4j=$(docker ps -a | grep transformation-advisor-neo4j | awk '{print $1}')

### start containers

docker start $couch
sleep 10
docker start $server
docker start $ui
docker start $neo4j

}

function stopTA {

ui=$(docker ps -a | grep transformation-advisor-ui | awk '{print $1}')
couch=$(docker ps -a | grep transformation-advisor-db | awk '{print $1}')
server=$(docker ps -a | grep transformation-advisor-server | awk '{print $1}')
graph=$(docker ps -a | grep transformation-advisor-neo4j | awk '{print $1}')

#### Stop All TA Docker Containers

echo ""

for a in $ui; do
        docker kill $a 2>/dev/null 
done

for b in $couch; do
        docker kill $b 2>/dev/null 
done

for c in $server; do
        docker kill $c 2>/dev/null 
done

for d in $graph; do
        docker stop $d 2>/dev/null 
done

podRun=$(which podman 2>&1)
if [[  "$podRun" ||  $podRun =~ "/usr/bin/podman" ]] && [[  $podRun =~ "/bin/podman" ]] ; then
pod=$(docker pod ps | grep ta_pod | awk '{print $1}')

for e in $pod; do
        docker pod rm -f $e 2>/dev/null
done
fi

echo ""

}

function removeContainers {

ui=$(docker ps -a | grep transformation-advisor-ui | awk '{print $1}')
couch=$(docker ps -a | grep transformation-advisor-db | awk '{print $1}')
server=$(docker ps -a | grep transformation-advisor-server | awk '{print $1}')
graph=$(docker ps -a | grep transformation-advisor-neo4j | awk '{print $1}')

#### Remove TA Containers ###################

for e in $ui; do
        docker rm -f $e
done

for f in $couch; do
        docker rm -f $f
done

for g in $server; do
        docker rm -f $g
done

for h in $graph; do
  docker rm -f $h
done

}

function removeVolumes {

if [[ $TA_LOCAL_TEMP_DOCKER_INSTALL = true ]]; then
  dbVol=`docker volume ls | grep tadb | awk '{print $2}'`
  if [[ ! -z $dbVol ]] ; then
   docker volume rm tadb tagraph
  fi
fi


if [[ $TA_LOCAL_TEMP_PODMAN_INSTALL = true ]]; then
        dbVol=`docker volume ls | grep tadb | awk '{print $2}'`
  if [[ ! -z $dbVol ]] ; then
   docker volume rm tadb tagraph
  fi
fi


}



